@@ -54,7 +54,7 @@ def to_dvc(
     write: bool = False,
     verbose: bool = False,
 ) -> dict:
-    """Transpile a Calkit pipeline to a DVC pipeline."""
+    """Compile a Calkit pipeline to a DVC pipeline."""
     if ck_info is None:
         ck_info = calkit.load_calkit_info(wdir=wdir)
     if "pipeline" not in ck_info:
@@ -64,34 +64,17 @@ def to_dvc(
     except Exception as e:
         raise ValueError(f"Pipeline is not defined properly: {e}")
     dvc_stages = {}
-    # First, create stages for checking/exporting all environments used in the
-    # pipeline
+    # First, gather up any env lock paths we might need for DVC deps
     used_envs = set([stage.environment for stage in pipeline.stages.values()])
     env_lock_fpaths = {}
     for env_name, env in ck_info.get("environments", {}).items():
         if env_name not in used_envs:
             continue
-        env_fpath = env.get("path")
         lock_fpath = get_env_lock_fpath(
-            env=env, env_name=env_name, as_posix=True
+            env=env, env_name=env_name, as_posix=True, for_dvc=True
         )
-        cmd = f"calkit check environment --name {env_name}"
         if lock_fpath is None:
             continue
-        deps = []
-        outs = []
-        if env_fpath is not None:
-            deps.append(env_fpath)
-        # Docker envs sometimes have deps, so add those too
-        if env.get("deps", []):
-            deps += env["deps"]
-        outs.append({lock_fpath: dict(cache=False, persist=True)})
-        stage = dict(cmd=cmd, deps=deps, outs=outs, always_changed=True)
-        stage["desc"] = (  # type: ignore
-            "Automatically generated by Calkit. "
-            "Changes made here will be overwritten."
-        )
-        dvc_stages[f"_check-env-{env_name}"] = stage
         env_lock_fpaths[env_name] = lock_fpath
     project_params = expand_project_parameters(ck_info.get("parameters", {}))
     # Now convert Calkit stages into DVC stages
@@ -181,30 +164,23 @@ def to_dvc(
             "in calkit.yaml. Changes made here will be overwritten."
         )
         dvc_stage["desc"] = desc
-        # If this is a Jupyter Notebook stage, we need to add a clean stage
-        if stage.kind == "jupyter-notebook":
-            clean_stage_name = f"_clean-nb-{stage_name}"
-            dvc_stages[clean_stage_name] = stage.dvc_clean_stage
-            dvc_stages[clean_stage_name]["desc"] = desc
         dvc_stages[stage_name] = dvc_stage
-        # Check for any outputs that should be ignored
+        # Check for any outputs that should be ignored/unignored
         if write:
             repo = git.Repo(wdir)
             # Ensure we catch any Jupyter Notebook outputs
             outputs = stage.outputs.copy()
             if stage.kind == "jupyter-notebook":
                 outputs += stage.notebook_outputs
+            elif stage.kind == "sbatch":
+                outputs.append(stage.log_output)
+            # Deal with any gitignore changes necessary
             for out in outputs:
-                if (
-                    isinstance(out, PathOutput)
-                    and out.storage is None
-                    and not repo.ignored(out.path)
-                ):
-                    gitignore_path = ".gitignore"
-                    if wdir is not None:
-                        gitignore_path = os.path.join(wdir, gitignore_path)
-                    with open(gitignore_path, "a") as f:
-                        f.write("\n" + out.path + "\n")
+                if isinstance(out, PathOutput) and out.storage is None:
+                    calkit.git.ensure_path_is_ignored(repo, path=out.path)
+                # Unignore path if necessary
+                elif isinstance(out, PathOutput) and out.storage == "git":
+                    calkit.git.ensure_path_is_not_ignored(repo, path=out.path)
     # Now process any inputs from stage outputs
     for stage_name, stage in pipeline.stages.items():
         for i in stage.inputs:
