@@ -257,6 +257,7 @@ def test_run_in_julia_env(tmp_dir):
             "julia-env",
             "-n",
             "my-julia",
+            "--julia=1.11",
             "--no-commit",
             "Revise",
             "PkgVersion",
@@ -270,6 +271,7 @@ def test_run_in_julia_env(tmp_dir):
                 "-n",
                 "my-julia",
                 "--",
+                "-e",
                 (
                     "using Revise; using PkgVersion; "
                     "println(PkgVersion.Version(Revise))"
@@ -279,8 +281,36 @@ def test_run_in_julia_env(tmp_dir):
         .decode()
         .strip()
     )
-    # TODO: Allow specifying version
-    assert out
+    # Check that we can run a script with arguments
+    with open("julia_script.jl", "w") as f:
+        f.write(
+            "import PkgVersion; "
+            " using Revise; "
+            'println("PkgVersion: ", PkgVersion.Version(Revise)); '
+            'println("Arg1: ", ARGS[1]); '
+            'println("Arg2: ", ARGS[2])'
+        )
+    out = (
+        subprocess.check_output(
+            [
+                "calkit",
+                "xenv",
+                "--no-check",
+                "-n",
+                "my-julia",
+                "--verbose",
+                "--",
+                "julia_script.jl",
+                "hello",
+                "world",
+            ]
+        )
+        .decode()
+        .strip()
+    )
+    assert "PkgVersion" in out
+    assert "Arg1: hello" in out
+    assert "Arg2: world" in out
 
 
 def test_to_shell_cmd():
@@ -573,3 +603,40 @@ def test_stage_run_info_from_log_content():
             "status": "failed",
         },
     }
+
+
+def test_map_paths(tmp_dir):
+    subprocess.check_call(["calkit", "init"])
+    os.makedirs("paper", exist_ok=True)
+    with open("test.txt", "w") as f:
+        f.write("This is a test file.")
+    subprocess.check_call(
+        ["calkit", "map-paths", "--file-to-file", "test.txt->paper/test.txt"]
+    )
+    assert os.path.isfile("paper/test.txt")
+    with open("paper/test.txt", "r") as f:
+        content = f.read()
+    assert content == "This is a test file."
+    with open(".gitignore") as f:
+        gitignore = f.read()
+    assert "paper/test.txt" in gitignore.split("\n")
+    os.makedirs("data", exist_ok=True)
+    with open("data/file1.txt", "w") as f:
+        f.write("This is file 1.")
+    with open("data/file2.txt", "w") as f:
+        f.write("This is file 2.")
+    subprocess.check_call(
+        ["calkit", "map-paths", "--dir-to-dir-merge", "data->paper/data"]
+    )
+    assert os.path.isfile("paper/data/file1.txt")
+    assert os.path.isfile("paper/data/file2.txt")
+    os.remove("data/file1.txt")
+    subprocess.check_call(
+        ["calkit", "map-paths", "--dir-to-dir-replace", "data->paper/data"]
+    )
+    assert not os.path.isfile("paper/data/file1.txt")
+    assert os.path.isfile("paper/data/file2.txt")
+    subprocess.check_call(
+        ["calkit", "map-paths", "--file-to-dir", "test.txt->paper/data"]
+    )
+    assert os.path.isfile("paper/data/test.txt")
